==> yst-sale-api-1.1.1.05-20230512.032217-2-sources.jar: com/elitesland/sale/dto/SalemanCustDTO.java <==
package com.elitesland.sale.dto;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.util.List;

@Data
public class SalemanCustDTO implements Serializable {

    private static final long serialVersionUID = 3552385740808330327L;
    @ApiModelProperty("客户编号")
    private String custCode;

    @ApiModelProperty("客户号")
    private String custCode2;

    @ApiModelProperty("客户简称")
    private String custAbbr;

    @ApiModelProperty("客户名称")
    private String custName;

    @ApiModelProperty("区域")
    private String region;

    @ApiModelProperty("业务员路径")
    private List<path> Salesman_path;

    @ApiModelProperty("id")
    private Long id;

    /**
     *业务员编号
     */
    @ApiModelProperty("业务员编号")
    private String salesmanNo;

    @ApiModelProperty("业务员Id")
    private Long salesmanId;

    /**
     *业务员名称
     */
    @ApiModelProperty("业务员名称")
    private String salesmanName;

    /**
     *区域经理编号
     */
    @ApiModelProperty("区域经理编号")
    private String remanageNo;

    @ApiModelProperty("区域经理id")
    private Long remanageId;
    /**
     *区域经理名称
     */
    @ApiModelProperty("区域经理名称")
    private String remanagerName;

    /**
     *省区经理编号
     */
    @ApiModelProperty("省区经理编号")
    private String prmanagerNo;

    @ApiModelProperty("省区经理Id")
    private Long prmanagerId;

    /**
     *省区经理名称
     */
    @ApiModelProperty("省区经理名称")
    private String prmanagerName;

    /**
     *总监编号
     */
    @ApiModelProperty("总监编号")
    private String chiefNo;

    @ApiModelProperty("总监id")
    private Long chiefId;

    /**
     *总监名称
     */
    @ApiModelProperty("总监名称")
    private String chiefName;

    @Data
    public static class path implements Serializable {
        private static final long serialVersionUID = 7397368816557582968L;
        private String code;
        private String type;
        private Integer level;
        private String name;
    }
    
}

==> yst-sale-api-1.1.1.508.100-20251031.030215-1-sources.jar: com/elitesland/sale/dto/SalemanCustDTO.java <==
package com.elitesland.sale.dto;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.util.List;

@Data
public class SalemanCustDTO implements Serializable {

    private static final long serialVersionUID = 3552385740808330327L;
    @ApiModelProperty("客户编号")
    private String custCode;

    @ApiModelProperty("客户号")
    private String custCode2;

    @ApiModelProperty("客户简称")
    private String custAbbr;

    @ApiModelProperty("客户名称")
    private String custName;

    @ApiModelProperty("区域")
    private String region;

    @ApiModelProperty("业务员路径")
    private List<SalesmanLevelInfoDTO.path> path;

    @ApiModelProperty("id")
    private Long id;

    @ApiModelProperty("pid")
    private String pid;

    /**
     *业务员编号
     */
    @ApiModelProperty("业务员编号")
    private String salesmanNo;

    @ApiModelProperty("业务员Id")
    private Long salesmanId;

    /**
     *业务员名称
     */
    @ApiModelProperty("业务员名称")
    private String salesmanName;

    /**
     *区域经理编号
     */
    @ApiModelProperty("区域经理编号")
    private String remanageNo;

    @ApiModelProperty("区域经理id")
    private Long remanageId;
    /**
     *区域经理名称
     */
    @ApiModelProperty("区域经理名称")
    private String remanagerName;

    /**
     *省区经理编号
     */
    @ApiModelProperty("省区经理编号")
    private String prmanagerNo;

    @ApiModelProperty("省区经理Id")
    private Long prmanagerId;

    /**
     *省区经理名称
     */
    @ApiModelProperty("省区经理名称")
    private String prmanagerName;

    /**
     *总监编号
     */
    @ApiModelProperty("总监编号")
    private String chiefNo;

    @ApiModelProperty("总监id")
    private Long chiefId;

    /**
     *总监名称
     */
    @ApiModelProperty("总监名称")
    private String chiefName;

//    @Data
//    public static class path implements Serializable {
//        private static final long serialVersionUID = 7397368816557582968L;
//        private String code;
//        private String type;
//        private Integer level;
//        private String name;
//    }
    
}
